@@ -1,5 +1,6 @@
 import stactools.core
 from .dataset import Dataset
+from .errors import CogifyError
 
 stactools.core.use_fsspec()
 
@@ -9,6 +10,6 @@ def register_plugin(registry):
     registry.register_subcommand(commands.create_goes_command)
 
 
-__all__ = [Dataset]
-__version__ = '0.1.0'
+__all__ = [Dataset, CogifyError]
+__version__ = '0.1.2'
 """Library version"""
